#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
# the test suite builds platform specific libraries, failing on some
ExcludeArch:    %arm ppc64le
%define configureargs --enable-tests
%else
%define psuffix %{nil}
%bcond_with test
# the resulting python library is pure
BuildArch:      noarch
%endif

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%define _name   pyatspi
Name:           python-atspi%{psuffix}
Version:        2.46.0
Release:        1.4
Summary:        Python bindings for the Assistive Technology Service Provider Interface
License:        LGPL-2.0-only
Group:          Development/Libraries/Python
URL:            https://gitlab.gnome.org/GNOME/pyatspi2
Source0:        https://download.gnome.org/sources/pyatspi/2.46/%{_name}-%{version}.tar.xz
BuildRequires:  %{python_module dbus-python}
BuildRequires:  %{python_module gobject >= 2.90.1}
BuildRequires:  %{python_module gobject-devel >= 2.90.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
# Needed to have typelib() Requires.
BuildRequires:  gobject-introspection
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(gtk+-3.0)
%if %{with test}
BuildRequires:  at-spi2-core
BuildRequires:  glib2-devel
BuildRequires:  libxml2-devel
BuildRequires:  (at-spi2-atk-gtk2 if at-spi2-core < 2.45)
BuildRequires:  (atk-devel if at-spi2-core-devel < 2.45)
%endif
Requires:       python-dbus-python
Requires:       python-gobject >= 2.90.1
# The bindings are really useful only if the at-spi registry is running. But
# it's not a strict runtime dependency.
Recommends:     at-spi2-core
# Old versions of at-spi 1.x provided the same files
Conflicts:      at-spi < 1.29.3
# Virtual package, so that apps can depend on it, without having to know which
# at-spi stack is used. Only the default at-spi stack should define it.
# DEPRECATED: For python packages, use Requires: python-pyatspi and let the
# python_subpackages macro figure out the correct package.
%ifpython2
Provides:       py2atspi
Provides:       pyatspi
%endif
%if "%{python_flavor}" == "python3" || "%{?python_provides}" == "python3"
Provides:       py3atspi
%endif
%python_subpackages

%description
AT-SPI is a general interface for applications to make use of the
accessibility toolkit. This version is based on dbus.

This package contains the python bindings for AT-SPI.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
# Configure for out-of-tree builds
%define _configure ../configure

%{python_expand mkdir build_%{$python_bin_suffix}
pushd build_%{$python_bin_suffix}
export PYTHON=%_bindir/$python
%configure %{?configureargs}
make %{?_smp_mflags}
popd
}

%install
%if ! %{with test}
%{python_expand pushd build_%{$python_bin_suffix}
%make_install
popd
}
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
# does not work with -z now due to some library overriding
export SUSE_ZNOW=0
%{python_expand pushd build_%{$python_bin_suffix}/tests
dbus-run-session make %{?_smp_mflags} check CFLAGS="-Wno-return-type" || (cat pyatspi/test-suite.log && exit 1)
popd
}
%endif

%if ! %{with test}
%files %{python_files}
%license COPYING
%doc AUTHORS NEWS README
%{python_sitelib}/pyatspi/
%endif

%changelog
* Wed Sep 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.46.0:
  + No changes, stable bump only.
* Mon Aug 29 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Only BuildRequire at-spi2-atk-gtk2 and atk-devel if
  at-spi2-core < 2.45. In newer versions, at-spi2-atk was merged
  into -core and obsoleted.
* Mon Aug  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.45.90:
  + Add object:announcement to the list of events.
  + Add support for ATSPI_ROLE_PUSH_BUTTON_MENU.
* Tue Mar 29 2022 Marcus Meissner <meissner@suse.com>
- link testsuite with -z lazy to avoid breaking the build.
* Fri Feb 11 2022 pgajdos@suse.com
- 2to3 module is not required for build
* Wed Dec  8 2021 Michael Gorse <mgorse@suse.com>
- Update to version 2.38.2:
  + Fix a missing return value in the testsuite.
  + Make Selection#clearSelection work.
  + Fix attributeListToHash() in case there’s a colon in an attr
    value.
- Drop pyatspi-test-fixes.patch: fixed upstream.
* Mon Sep 27 2021 Michael Gorse <mgorse@suse.com>
- Add pyatspi-test-fixes.patch: fix tests on s390x (bsc#1190051).
* Wed Aug 11 2021 Yifan Jiang <yfjiang@suse.com>
- Drop build with python2.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.38.1:
  + Add sanity checks to getPath and findAncestor so that we don't
    hang if an accessible returns itself as its own parent.
* Mon Dec 14 2020 Benjamin Greiner <code@bnavigator.de>
- Support future multiple python3 flavors
  * fix py*atspi provides
  * remove %%ifpython3 -- it will break
  * gh#openSUSE/python-rpm-macros#66
- Enable testsuite. General rule for python packages: must run if
  they are available. And it revealed a problem with the
  (not given) path to the python interpreter.
  * The test suite compiles test libraries which do not work for
    armv7l and ppc64le. Skip there.
* Mon Sep 14 2020 dimstar@opensuse.org
- Update to version 2.38.0:
  + Updated translations.
* Fri Sep  4 2020 dimstar@opensuse.org
- Update to version 2.37.90:
  + Tests: use libatspi's dbus-gmain implementation, eliminating
    dependency on dbus-glib.
  + Migrate to gtk 3.
  + Add support for the mode-changed signal.
- Add pkgconfig(gtk+-3.0) BuildRequires: align with what configure
  is looking for.
* Sun Mar  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.36.0:
  + No changes, stable release bump only.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 2.35.1:
  + Fix dead link in README.
  + Adjust accepted test results for python 3.8 compatibility.
  + Add ROLE_MARK and ROLE_SUGGESTION.
* Mon Sep  9 2019 mgorse@suse.com
- Update to version 2.34.0:
  + Updated doap, and include it in the tarball.
* Mon Sep  2 2019 mgorse@suse.com
- Update to version 2.33.92:
  + Several test fixes.
  + Add license header on some test files.
* Fri Aug 30 2019 mgorse@suse.com
- Update to version 2.33.90:
  + Fix typo in get_imageLocale.
  + event.str(): show event sender.
  + Remove wrapper for atspi_text_notify_reading_position,
    as the function has been removed from at-spi2-core.
  + events: replace object:text:reading-position with
    screen-reader:region-changed.
  + Add wrapper for atspi_set_reference_window.
- Changes from version 2.33.2:
  + Add support for ROLE_CONTENT_DELETION and
    ROLE_CONTENT_INSERTION.
- Changes from version 2.33.1:
  + Add accessibleId property.
  + Add text.notifyReadingPosition.
  + Fix print usage in example, for python 3 compatibility.
* Thu Apr 18 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid use of em dashes in titles.
* Wed Apr 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.32.1:
  + Fix arguments in Text.addSelection.
  + Document that extents are only meaningful when both visible and
    showing.
  + Fix default kind value for registerKeystrokeListener.
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.32.0:
  + Stable release version bump.
* Wed Feb 20 2019 bjorn.lie@gmail.com
- Update to version 2.31.2:
  + Add ScrollSubstringTo and ScrollSubstringToPoint text
    interfaces.
* Tue Jan  8 2019 bjorn.lie@gmail.com
- Update to version 2.31.1:
  + Add support for locking/unlocking modifiers.
* Fri Sep  7 2018 bjorn.lie@gmail.com
- Update to version 2.30.0:
  + No changes, stable bump only.
* Thu Aug 16 2018 bjorn.lie@gmail.com
- Update to version 2.29.90:
  + registry: Rename async keyword for compatibility with Python
    3.7.
  + Add missing XY_PARENT export.
* Tue Jun 19 2018 bjorn.lie@gmail.com
- Update to version 2.29.1:
  + Add ScrollTo and ScrollToPoint component interfaces.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Sep 12 2017 luc14n0@linuxmail.org
- Update to version 2.26.0:
  + Single commit.
* Tue Jun 20 2017 dimstar@opensuse.org
- Update to version 2.25.3:
  + Add error-message, error-for, details, and details-for relation
    types.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 2.25.2:
  + Add some missing roles to correspond with atk (description
    list, description term, description value, and footnote).
* Thu Apr 27 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 2.24.0:
  + Fix an invalid escape sequence.
  + Rename enum class to atspienum to avoid name conflict; fixes
    build with python 3.6.
* Tue Jan 17 2017 dimstar@opensuse.org
- Update to version 2.20.3:
  + Rename enum module and Enum class not to conflict with stdlib
    (needed for python 3.6).
* Fri May 20 2016 mgorse@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Tue May 10 2016 zaitor@opensuse.org
- Update to version 2.20.2:
  + Update STATE_LAST_DEFINED so that STATE_READ_ONLY is recognized
    (bgo#766121).
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 2.20.1:
  + gettext: Don't modify endOffset (bgo#721860).
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 2.20.0:
  + No changes, stable release.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 2.19.91:
  + Call gi.require_version() before import.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 2.18.0:
  + No changes, stable release.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 2.17.90:
  + Fix text.getDefaultAttributeSet (bgo#752928).
* Tue Mar 24 2015 zaitor@opensuse.org
- Update to version 2.16.0:
  + No changes, stable bump.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 2.15.90:
  + Add new roles for fractions, roots, subscripts, and
    superscripts (bgo#743413).
* Wed Jan 28 2015 zaitor@opensuse.org
- Update to version 2.15.4:
  + Support ATSPI_STATE_READ_ONLY (bgo#690108).
* Thu Dec 18 2014 zaitor@opensuse.org
- Update to version 2.15.3:
  + Add ROLE_STATIC (bgo#740364).
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 2.14.0:
  + Test fixes.
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 2.12.0:
  + Stable release, no changes since 2.11.92.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 2.11.92:
  + Fix a traceback when removing a text selection.
* Wed Feb 19 2014 zaitor@opensuse.org
- Update to version 2.11.90:
  + Add AtspitableCell, tracking the new atk interface.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 2.11.3:
  + bgo#719508: document: add support to current page and page
    count.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 2.11.2:
  + Add new roles and states to track atk (bgo#710464, bgo#712608,
    bgo#712609).
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 2.10.0:
  + No changes since version 2.9.92.
* Mon Sep 16 2013 zaitor@opensuse.org
- Update to version 2.9.92:
  + Handle attribute lists with multiple accepted values for the
    same key when creating a collection match rule (bgo#700865).
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 2.9.90:
  + Added getStringAtOffset.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 2.9.3:
  + Add some examples (bgo#701063).
  + Removed setting of AT_SPI_CLIENT, as it is no longer used as of
    at-spi2-core 2.9.3.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 2.9.2:
  + Update for libatspi API changes (bgo#700243).
* Fri Apr 19 2013 dimstar@opensuse.org
- Add support for python 3:
  + New package / spec file for python3-atspi.
  + pre_checkin.sh: syncronize python-atspi and python3-atspi.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 2.8.0:
  + No changes since version 2.7.91.
* Mon Mar  4 2013 zaitor@opensuse.org
- Update to version 2.7.91:
  + Add objectLocale property (bgo#694368).
  + Stop using a deprecated method.
  + Don't install the example, since it isn't compatible with
    Python3.
- Drop our hack in spec that removed the above mentioned example.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 2.7.5:
  + Support new levelbar role.
* Sat Jan 12 2013 dimstar@opensuse.org
- Update to version 2.7.2:
  + Add a --with-python option to configure.ac.
  + Fix getCharacterAtOffset.
* Wed Oct 24 2012 dimstar@opensuse.org
- Update to version 2.7.1:
  + Export application class in the Accessibility namespace, for
    backwards compatibility.
* Tue Oct 23 2012 dimstar@opensuse.org
- Do not install magFocusTracker.py sample applications. Useless
  for normal users and in plus it introduces an unversioned
  typelib(Gdk) dependency, which causes unresolvables in Factory.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 2.6.0:
  + Install caret focus tracker into $bindir, rather than
    $pythondir/examples.
  + Fix incorrect FSF address in file headers.
* Tue Sep 18 2012 zaitor@opensuse.org
- Update to version 2.5.92:
  + Fix missing argument for set_current_value method (bgo#683302).
  + Include interim focus tracker as an example.
- Add hack to set executable bit to example interim focus tracker.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 2.5.91:
  + Fix autogen.sh for non-sourcedir build.
* Mon Aug  6 2012 dimstar@opensuse.org
- Update to version 2.5.5:
  + Add getLocalizedName for actions.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 2.5.4:
  + Wrap all interfaces (bgo#679044).
* Wed Jun 27 2012 dimstar@opensuse.org
- Update to version 2.5.3:
  + Fix truth evaluation for accessibles in Python 3.
  + dict.iteritems() is no longer supported in Python 3
    (bgo#678497)
  + Re-add setTimeout (it seems that it was lost among the Python 3
    updates).
- Changes from version 2.5.2:
  + More Python 3 fixes.
  + Fix getStates regression (bgo#677070)
* Tue May  1 2012 dimstar@opensuse.org
- Update to version 2.5.1:
  + Add setTimeout.
  + Some clean-ups for Python 3.
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 2.4.0:
  + No changes.
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 2.3.92:
  + Another fix for --enable-tests.
* Tue Mar  6 2012 vuntz@opensuse.org
- Update to version 2.3.91:
  + Fix --enable-tests.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 2.3.5:
  + bgo#660826: Drop unneeded pygtk check.
  + Remove exception wrapping: pyatspi will now return the real
    exception as translated by pygi, rather than LookupError.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Mon Jan 16 2012 vuntz@opensuse.org
- Update to version 2.3.4:
  + bgo#666871: deregisterKeystrokeListener was broken.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Remove checks for old non-maintained versions of openSUSE (11.1
  and earlier).
* Tue Oct 18 2011 vuntz@opensuse.org
- Update to version 2.2.1:
  + Use hasattr rather than a try in registerEventListener, for
    performance.
  + bgo#661613: getOffsetAtPoint now works.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 2.2.0:
  + No change, just a version bump.
* Fri Sep  9 2011 vuntz@opensuse.org
- Update to version 2.1.91:
  + bgo#658343: Have configure check for pygobject-3.0
- Change pkgconfig(pygobject-2.0) BuildRequires to
  pkgconfig(pygobject-3.0), following upstream change.
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 2.1.90:
  + Fix getTextBeforeOffset.
  + Remove legacy pygtk dependency.
- Drop python-atspi-quotes.patch: fixed upstream.
- Add gobject-introspection BuildRequires so that we can have
  automatic typelib() Requires.
- Remove libatspi0 Requires: this is replaced by an automatic
  typelib() Requires.
- Remove python-gtk Requires: this is not needed anymore.
- Remove python-xlib Requires: the Xlib module is not used at all.
- Replace python-gobject2 Requires with python-gobject as the
  module requires the introspection-powered python-gobject.
- Remove gconf2 Recommends: it was only needed to support relocated
  pyatspi-corba, and this support is gone since 2.1.5.
* Thu Aug 18 2011 dimstar@opensuse.org
- Add python-atspi-quotes.patch: Add back an accidentally dropped
  closing quote. Patch taken from git, commit 890bd7.
* Tue Aug 16 2011 dimstar@opensuse.org
- Update to version 2.1.5:
  + Remove support for relocated pyatspi-corba.
  + Fix getTextBeforeOffset.
* Tue Jul 26 2011 vuntz@opensuse.org
- Update to version 2.1.4:
  + Update to handle libatspi API changes.
  + bgo#653874: new ATK roles.
* Tue Jul  5 2011 vuntz@opensuse.org
- Update to version 2.1.3:
  + bgo#644393: Remove document:content-changed from EVENT_TREE
* Thu Jun 16 2011 vuntz@opensuse.org
- Update to version 2.1.2:
  + Merge changes from 2.0.2.
  + Add atspiVersion().
  + Fix makeSyncType to generate a proper enum (will be needed when
    enum-types branch of at-spi2-core is merged).
  + Add clearCache().
  + Cache eventTypes in events for performance reasons.
  + Add GPL2 license because a couple of test files are licensed
    under it.
* Tue May 31 2011 fcrozat@suse.com
- Update to version 2.0.2:
  + Fix traceback when calling document functions.
  + Fix traceback when creating match rules with attribute sets.
  + Fix several table functions.
* Tue Apr 26 2011 fcrozat@novell.com
- Update to version 2.0.1:
  + bgo#645644: Throw LookupError rather than RuntimeError.
  + Add id property.
  + Add a work-around for getStates failing on 64-bit systems with
    pygobject 2.28.3 and earlier.
* Thu Apr 21 2011 vuntz@opensuse.org
- Add gconf2 Recommends as gconftool-2 is used when the module is
  loaded to know if the corba-based stack should be preferred
  instead.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 2.0.0:
  + Removed some unused files.
- Changes from version 1.91.92:
  + Added some missing __str__ functions for events and accessibles
- Changes from version 1.91.91:
  + bgo#643384: registerKeystrokeListener should pass a bit mask,
    not an enum.
- Changes from version 1.91.90:
  + Refactor EditableText so that text methods can be called from
    it.
  + Make state accessible through pyatspi.constants.
  + Fix selection interface.
  + bgo#641869: Remove --enable-relocate option.
- Changes from version 1.91.6:
  + Added source_name and source_role to events.
  + Call gconftool-2 to check the value of
    /desktop/gnome/interface/at-spi-corba rather than importing
    gconf, since the latter can cause problems if new and old
    versions of the Python bindings are mixed.
  + Added setExtents, setSize, and setPosition for components.
  + Added setCacheMask.
- Changes from version 1.91.5:
  + Fixed generateKeyboardEvent, description, and allModifiers.
  + Added a dummy stateset.unref function for backwards
    compatibility.
  + Added a pumpQueuedEvents stub.
  + Added RELATION_EMBEDDED_BY.
  + Hide children attribute since it is currently broken and caused
    a crash with Accerciser..
  + Wrap event type so that sub-fields can be accessed.
- Changes from version 1.91.4:
  + Added a dummy freeMatchRule function.
  + Attribute fixes.
  + __getitem__ now supports negative indices.
  + Fixed some properties, relationToString, listInterfaces,
    various text methods.
  + Raise notImplementedError when querying unimplemented
    interfaces.
- Changes from version 1.91.3:
  + This is a major refactor using the C-based libatspi as a core.
    This should significantly improve performance.  However, this
    release is very buggy and is more of a development snapshot
    than a usable release.
- Changes from version 1.91.1:
  + Add configure check for python-xlib
  + Have calls on the async bus time out after 2 seconds
  + Added a LRU cache for objects that use the soft cache
- Changes from version 1.91.0:
  + --disable-relocate is the default again.
  + Added a "soft cache" to try to avoid repeatedly querying for
    information in cases where we never received an
    AccessibleAdded signal for an object.
- Requires libatspi0, needed for introspection to work correctly.
- Remove the IS_DEFAULT_SPI_STACK handling, this is the default
  stack and it is no longer configurable.
- Replace BuildRequires on python with pkgconfig(pygobject-2.0).
* Thu Nov 18 2010 vuntz@opensuse.org
- Update to version 0.4.1:
  + Add configure check for python-xlib.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 0.4.0:
  + Version bump to stable 0.4.0, without any change.
* Tue Aug 31 2010 vuntz@opensuse.org
- Update to version 0.3.91:
  + Enable relocate by default for now.
  + Ensure that queued events are delivered when calling
    registry.stop().
  + If an unexpected exception is thrown when checking for the
    accessibility bus (ie, python-xlib is missing), throw the
    exception rather than silently reverting to the session bus.
* Tue Aug 24 2010 vuntz@opensuse.org
- Add python-xlib Requires. Thanks to Mike Gorse for noticing this.
* Tue Aug 17 2010 dimstar@opensuse.org
- Update to version 0.3.90:
  + Have registerEventListener an deregisterEventListener notify
    the registry, as is now needed.
  + Avoid raising an event multiple times if EVENT_TREE is used to
    register for all events.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 0.3.6:
  + Some thread safety fixes; should no longer deadlock when
    listening for events using Strongwind.
- Changes from version 0.3.4:
  + Listen for AddAccessible and RemoveAccessible at the
  DesktopCache level. This fixes a regression with Firefox for
  instance that was introduced in v0.3.3.
* Fri Jun  4 2010 sshaw@decriptor.com
- Update to version 0.3.3:
  + Hyperlink fixes.
  + When an object's parent is set to null, remove it from the
    parent in the cache.
  + Fix an issue where a state-changed handler can be called before
    the cache received the signal and updated the state.
  + Only range check for __getitem__, not getChildAtIndex. This is
    pyatspi-corba's behavior and should improve performance in some
    cases.
  + Fix tracebacks when checking some event properties.
  + Fix a traceback when simulating a defunct state for an object
    that has gone away.
  + Fix traceback when calling queryDocument.getAttributes(),
    queryText().getCharacterExtents(), and
    queryValue().setCurrentValue().
  + Fix handling of some ChildrenChanged signals sent by Firefox.
- Update to version 0.3.2:
  + Remove double deletion of application from the desktop cache
    handler. Was causing a mostly harmless exception when an
    application shut down.
  + Role changes now update the cache.
  + Avoid throwing an exception in getState() if an object no
    longer exists. This avoids potentially throwing an eception
    where at-spi-corba may not.
  + Do not use the cache if registry.start() has not been called;
    allows simple scripts without a main loop to work better.
- Update to version 0.3.1.1:
  + Install to $PYTHONDIR again, since we have no arch-specific
    dependencies.
  + Do not dispatch events while waiting for a reply from a method
    call.
- Update to version 0.3.1:
  + Fixed GetLink, GetColumnHeader, getAccessibleAtPoint, and
    possibly others.
  + Fix children-changed, property-change::accessible-parent, and
    active-descendant-changed events.
  + Update an accessible's StateSet when a StateChanged signal is
    received.
  + Properly fetch children of MANAGES_DESCENDANTS objects (ie, do
    not use cache)
  + The desktop's role is now set to ROLE_DESKTOP_FRAME.
  + Use pyexecdir as a base rather than pythondir.
  + Disable relocation by default.
- This fixes a crash in firefox when at-spi2 is used, see
  bnc#611149.
* Wed Apr  7 2010 vuntz@opensuse.org
- Make this new at-spi stack optional again: the at-spi2 developers
  think it's safer to ship 11.3 with the old stack by default.
- Add a IS_DEFAULT_ATSPI_STACK define to easily change this
  behavior.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 0.1.8:
  + Support id property
  + Set AT_SPI_CLIENT for use by at-spi2-atk
  + Set ROLE_UNKNOWN for desktop for compatibility with CORBA
    at-spi
* Sun Feb 21 2010 vuntz@opensuse.org
- Update to version 0.1.7:
  + Change the interface name from org.freedesktop to org.a11y.
  + Add fix for name error that was causing unit tests to fail.
* Fri Feb 12 2010 vuntz@opensuse.org
- Update to version 0.1.6:
  + Make AT-SPI/CORBA the default and relocate AT-SPI/D-Bus
  + Move the application argument to the end of the event structure
  + Enable Re-entrancy within pyatspi.
  + Changes to properly update the cache and fix orca performance
    issues
  + Re-factor cache to use a single dictionary.
  + Fix property getting to use the correct interfaces.
  + Modify pyatspi to use the accessible object located on the
    registryd.
  + Fix an event bug
  + bgo#607077 - pyatspi2: magic to detect whether to use corba
    version or not can be broken
- Drop python-atspi-fix-no-gconf.patch: fixed upstream.
- Pass --disable-relocate to configure because we want at-spi2 by
  default.
* Fri Jan 15 2010 vuntz@opensuse.org
- Add python-atspi-fix-no-gconf.patch to make python-atspi work if
  the gconf bindings are not available.
* Tue Jan 12 2010 vuntz@opensuse.org
- Update to version 0.1.5:
  + For a full list of changes, see
    http://git.gnome.org/browse/pyatspi2/log/?id=PYATSPI_0_1_5
  + Move the allModifiers function in to deviceevent.py to resolve
    missing symbol error when registering keystrokes for all
    modifiers.
  + Use pyatspi_corba if /desktop/gnome/interface/at-spi-corba is
    True
  + Additional work on bgo#606251 - Handle CORBA vs. D-Bus choice
    better
  + Modifications to use the new leasing scheme.
  + Add application reference to the event structure.
  + Make the cache update on property or child-changed signals.
  + Add children-changed event emission for top-level accessibles.
  + Temporarily switch off re-entrancy.
* Tue Dec 22 2009 vuntz@opensuse.org
- Update to version 0.1.4:
  + For a full list of changes, see
    http://git.gnome.org/browse/pyatspi2/log/?id=PYATSPI_0_1_4
  + Fix 100%% CPU usage. The event dispatcher funtion was running
    continuously.
  + Addition of new 'Accessibility' D-Bus bus. The bus address is
    located using X properties.
  + Do not rely on cache for children of MANAGES_DESCENDANTS
    objects
  + Fixes to the Test desktop allowing the unit tests to be run in
    non-cached mode.
  + Fix the getAttributes method of the text api to return
    semicolon delimited string as required by accerciser.
  + Fix problem with children changed signal when adding or
    removing applications.
  + Change name of exception to new merged
    AccessibleObjectNoLongerAvailable exception.
  + Correct wrong method name in the 'Selection' interface.
  + Remove reference to 'interfaces' module that was causing error
    in orca test suite.
  + Modify selection interface to use the new out-of-process
    protocol for transferring accessible objects.
  + Added collection support
  + Perform type checking on Enumeration equality.
  + Fix inconsistencies in Table interface introduced by
    out-of-process and method name changes in the protocol.
  + Fix get_application errors. A check was not made to see if the
    application name was the Registry.
  + Fix name errors in table.py - use of 'interfaces' module.
  + Up the recursion limit. The '15' limit was met while running
    the orca test suite.
  + Fix name error in create_application method of the
    CachedDesktop.
  + Add a missing 'unref' function to the StateSet api. This
    function does nothing and is needed for compatibility with the
    CORBA class.
* Wed Dec  2 2009 vuntz@opensuse.org
- Initial package, based on a previous version of at-spi2-atk.
- Provide a pyatspi virtual package (that python-atspi-corba also
  provides).
